==> gnome-builder-3.16.0.tar.xz: gnome-builder-3.16.0/libide/ide-enums.c <==

/* Generated data (by glib-mkenums) */

#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

#include "ide-enums.h"

#include "ide-buffer.h"
#include "ide-source-view.h"

/* enumerations from "libide/ide-buffer.h" */
GType
ide_buffer_line_flags_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GFlagsValue values[] = {
            { IDE_BUFFER_LINE_FLAGS_NONE, "IDE_BUFFER_LINE_FLAGS_NONE", "none" },
            { IDE_BUFFER_LINE_FLAGS_ADDED, "IDE_BUFFER_LINE_FLAGS_ADDED", "added" },
            { IDE_BUFFER_LINE_FLAGS_CHANGED, "IDE_BUFFER_LINE_FLAGS_CHANGED", "changed" },
            { IDE_BUFFER_LINE_FLAGS_ERROR, "IDE_BUFFER_LINE_FLAGS_ERROR", "error" },
            { IDE_BUFFER_LINE_FLAGS_WARNING, "IDE_BUFFER_LINE_FLAGS_WARNING", "warning" },
            { IDE_BUFFER_LINE_FLAGS_NOTE, "IDE_BUFFER_LINE_FLAGS_NOTE", "note" },
            { 0, NULL, NULL }
        };
        etype = g_flags_register_static (g_intern_static_string ("IdeBufferLineFlags"), values);
    }
    return etype;
}

/* enumerations from "libide/ide-source-view.h" */
GType
ide_source_view_mode_type_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GEnumValue values[] = {
            { IDE_SOURCE_VIEW_MODE_TYPE_TRANSIENT, "IDE_SOURCE_VIEW_MODE_TYPE_TRANSIENT", "transient" },
            { IDE_SOURCE_VIEW_MODE_TYPE_PERMANENT, "IDE_SOURCE_VIEW_MODE_TYPE_PERMANENT", "permanent" },
            { IDE_SOURCE_VIEW_MODE_TYPE_MODAL, "IDE_SOURCE_VIEW_MODE_TYPE_MODAL", "modal" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static (g_intern_static_string ("IdeSourceViewModeType"), values);
    }
    return etype;
}

GType
ide_source_view_theatric_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GEnumValue values[] = {
            { IDE_SOURCE_VIEW_THEATRIC_EXPAND, "IDE_SOURCE_VIEW_THEATRIC_EXPAND", "expand" },
            { IDE_SOURCE_VIEW_THEATRIC_SHRINK, "IDE_SOURCE_VIEW_THEATRIC_SHRINK", "shrink" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static (g_intern_static_string ("IdeSourceViewTheatric"), values);
    }
    return etype;
}

GType
ide_source_view_movement_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GEnumValue values[] = {
            { IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_OFFSET, "IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_OFFSET", "previous-offset" },
            { IDE_SOURCE_VIEW_MOVEMENT_NEXT_OFFSET, "IDE_SOURCE_VIEW_MOVEMENT_NEXT_OFFSET", "next-offset" },
            { IDE_SOURCE_VIEW_MOVEMENT_NTH_CHAR, "IDE_SOURCE_VIEW_MOVEMENT_NTH_CHAR", "nth-char" },
            { IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_CHAR, "IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_CHAR", "previous-char" },
            { IDE_SOURCE_VIEW_MOVEMENT_NEXT_CHAR, "IDE_SOURCE_VIEW_MOVEMENT_NEXT_CHAR", "next-char" },
            { IDE_SOURCE_VIEW_MOVEMENT_FIRST_CHAR, "IDE_SOURCE_VIEW_MOVEMENT_FIRST_CHAR", "first-char" },
            { IDE_SOURCE_VIEW_MOVEMENT_FIRST_NONSPACE_CHAR, "IDE_SOURCE_VIEW_MOVEMENT_FIRST_NONSPACE_CHAR", "first-nonspace-char" },
            { IDE_SOURCE_VIEW_MOVEMENT_MIDDLE_CHAR, "IDE_SOURCE_VIEW_MOVEMENT_MIDDLE_CHAR", "middle-char" },
            { IDE_SOURCE_VIEW_MOVEMENT_LAST_CHAR, "IDE_SOURCE_VIEW_MOVEMENT_LAST_CHAR", "last-char" },
            { IDE_SOURCE_VIEW_MOVEMENT_NEXT_WORD_START, "IDE_SOURCE_VIEW_MOVEMENT_NEXT_WORD_START", "next-word-start" },
            { IDE_SOURCE_VIEW_MOVEMENT_NEXT_FULL_WORD_START, "IDE_SOURCE_VIEW_MOVEMENT_NEXT_FULL_WORD_START", "next-full-word-start" },
            { IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_WORD_START, "IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_WORD_START", "previous-word-start" },
            { IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_FULL_WORD_START, "IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_FULL_WORD_START", "previous-full-word-start" },
            { IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_WORD_END, "IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_WORD_END", "previous-word-end" },
            { IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_FULL_WORD_END, "IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_FULL_WORD_END", "previous-full-word-end" },
            { IDE_SOURCE_VIEW_MOVEMENT_NEXT_WORD_END, "IDE_SOURCE_VIEW_MOVEMENT_NEXT_WORD_END", "next-word-end" },
            { IDE_SOURCE_VIEW_MOVEMENT_NEXT_FULL_WORD_END, "IDE_SOURCE_VIEW_MOVEMENT_NEXT_FULL_WORD_END", "next-full-word-end" },
            { IDE_SOURCE_VIEW_MOVEMENT_SENTENCE_START, "IDE_SOURCE_VIEW_MOVEMENT_SENTENCE_START", "sentence-start" },
            { IDE_SOURCE_VIEW_MOVEMENT_SENTENCE_END, "IDE_SOURCE_VIEW_MOVEMENT_SENTENCE_END", "sentence-end" },
            { IDE_SOURCE_VIEW_MOVEMENT_PARAGRAPH_START, "IDE_SOURCE_VIEW_MOVEMENT_PARAGRAPH_START", "paragraph-start" },
            { IDE_SOURCE_VIEW_MOVEMENT_PARAGRAPH_END, "IDE_SOURCE_VIEW_MOVEMENT_PARAGRAPH_END", "paragraph-end" },
            { IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_LINE, "IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_LINE", "previous-line" },
            { IDE_SOURCE_VIEW_MOVEMENT_NEXT_LINE, "IDE_SOURCE_VIEW_MOVEMENT_NEXT_LINE", "next-line" },
            { IDE_SOURCE_VIEW_MOVEMENT_FIRST_LINE, "IDE_SOURCE_VIEW_MOVEMENT_FIRST_LINE", "first-line" },
            { IDE_SOURCE_VIEW_MOVEMENT_NTH_LINE, "IDE_SOURCE_VIEW_MOVEMENT_NTH_LINE", "nth-line" },
            { IDE_SOURCE_VIEW_MOVEMENT_LAST_LINE, "IDE_SOURCE_VIEW_MOVEMENT_LAST_LINE", "last-line" },
            { IDE_SOURCE_VIEW_MOVEMENT_LINE_PERCENTAGE, "IDE_SOURCE_VIEW_MOVEMENT_LINE_PERCENTAGE", "line-percentage" },
            { IDE_SOURCE_VIEW_MOVEMENT_LINE_CHARS, "IDE_SOURCE_VIEW_MOVEMENT_LINE_CHARS", "line-chars" },
            { IDE_SOURCE_VIEW_MOVEMENT_LINE_END, "IDE_SOURCE_VIEW_MOVEMENT_LINE_END", "line-end" },
            { IDE_SOURCE_VIEW_MOVEMENT_HALF_PAGE_UP, "IDE_SOURCE_VIEW_MOVEMENT_HALF_PAGE_UP", "half-page-up" },
            { IDE_SOURCE_VIEW_MOVEMENT_HALF_PAGE_DOWN, "IDE_SOURCE_VIEW_MOVEMENT_HALF_PAGE_DOWN", "half-page-down" },
            { IDE_SOURCE_VIEW_MOVEMENT_PAGE_UP, "IDE_SOURCE_VIEW_MOVEMENT_PAGE_UP", "page-up" },
            { IDE_SOURCE_VIEW_MOVEMENT_PAGE_DOWN, "IDE_SOURCE_VIEW_MOVEMENT_PAGE_DOWN", "page-down" },
            { IDE_SOURCE_VIEW_MOVEMENT_SCREEN_UP, "IDE_SOURCE_VIEW_MOVEMENT_SCREEN_UP", "screen-up" },
            { IDE_SOURCE_VIEW_MOVEMENT_SCREEN_DOWN, "IDE_SOURCE_VIEW_MOVEMENT_SCREEN_DOWN", "screen-down" },
            { IDE_SOURCE_VIEW_MOVEMENT_SCREEN_TOP, "IDE_SOURCE_VIEW_MOVEMENT_SCREEN_TOP", "screen-top" },
            { IDE_SOURCE_VIEW_MOVEMENT_SCREEN_MIDDLE, "IDE_SOURCE_VIEW_MOVEMENT_SCREEN_MIDDLE", "screen-middle" },
            { IDE_SOURCE_VIEW_MOVEMENT_SCREEN_BOTTOM, "IDE_SOURCE_VIEW_MOVEMENT_SCREEN_BOTTOM", "screen-bottom" },
            { IDE_SOURCE_VIEW_MOVEMENT_MATCH_SPECIAL, "IDE_SOURCE_VIEW_MOVEMENT_MATCH_SPECIAL", "match-special" },
            { IDE_SOURCE_VIEW_MOVEMENT_SCROLL_SCREEN_TOP, "IDE_SOURCE_VIEW_MOVEMENT_SCROLL_SCREEN_TOP", "scroll-screen-top" },
            { IDE_SOURCE_VIEW_MOVEMENT_SCROLL_SCREEN_CENTER, "IDE_SOURCE_VIEW_MOVEMENT_SCROLL_SCREEN_CENTER", "scroll-screen-center" },
            { IDE_SOURCE_VIEW_MOVEMENT_SCROLL_SCREEN_BOTTOM, "IDE_SOURCE_VIEW_MOVEMENT_SCROLL_SCREEN_BOTTOM", "scroll-screen-bottom" },
            { IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_UNMATCHED_BRACE, "IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_UNMATCHED_BRACE", "previous-unmatched-brace" },
            { IDE_SOURCE_VIEW_MOVEMENT_NEXT_UNMATCHED_BRACE, "IDE_SOURCE_VIEW_MOVEMENT_NEXT_UNMATCHED_BRACE", "next-unmatched-brace" },
            { IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_UNMATCHED_PAREN, "IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_UNMATCHED_PAREN", "previous-unmatched-paren" },
            { IDE_SOURCE_VIEW_MOVEMENT_NEXT_UNMATCHED_PAREN, "IDE_SOURCE_VIEW_MOVEMENT_NEXT_UNMATCHED_PAREN", "next-unmatched-paren" },
            { IDE_SOURCE_VIEW_MOVEMENT_NEXT_MATCH_MODIFIER, "IDE_SOURCE_VIEW_MOVEMENT_NEXT_MATCH_MODIFIER", "next-match-modifier" },
            { IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_MATCH_MODIFIER, "IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_MATCH_MODIFIER", "previous-match-modifier" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static (g_intern_static_string ("IdeSourceViewMovement"), values);
    }
    return etype;
}



/* Generated data ends here */

==> gnome-builder-3.17.92.tar.xz: gnome-builder-3.17.92/libide/ide-enums.c <==

/* Generated data (by glib-mkenums) */

#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

#include "ide-enums.h"

#include "ide-buffer.h"
#include "ide-diagnostic.h"
#include "ide-doap.h"
#include "ide-highlighter.h"
#include "ide-indent-style.h"
#include "ide-source-view.h"
#include "ide-symbol.h"
#include "ide-thread-pool.h"

/* enumerations from "./doap/ide-doap.h" */
GType
ide_doap_error_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GEnumValue values[] = {
            { IDE_DOAP_ERROR_INVALID_FORMAT, "IDE_DOAP_ERROR_INVALID_FORMAT", "format" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static (g_intern_static_string ("IdeDoapError"), values);
    }
    return etype;
}

/* enumerations from "./ide-buffer.h" */
GType
ide_buffer_line_flags_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GFlagsValue values[] = {
            { IDE_BUFFER_LINE_FLAGS_NONE, "IDE_BUFFER_LINE_FLAGS_NONE", "none" },
            { IDE_BUFFER_LINE_FLAGS_ADDED, "IDE_BUFFER_LINE_FLAGS_ADDED", "added" },
            { IDE_BUFFER_LINE_FLAGS_CHANGED, "IDE_BUFFER_LINE_FLAGS_CHANGED", "changed" },
            { IDE_BUFFER_LINE_FLAGS_ERROR, "IDE_BUFFER_LINE_FLAGS_ERROR", "error" },
            { IDE_BUFFER_LINE_FLAGS_WARNING, "IDE_BUFFER_LINE_FLAGS_WARNING", "warning" },
            { IDE_BUFFER_LINE_FLAGS_NOTE, "IDE_BUFFER_LINE_FLAGS_NOTE", "note" },
            { 0, NULL, NULL }
        };
        etype = g_flags_register_static (g_intern_static_string ("IdeBufferLineFlags"), values);
    }
    return etype;
}

/* enumerations from "./ide-diagnostic.h" */
GType
ide_diagnostic_severity_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GEnumValue values[] = {
            { IDE_DIAGNOSTIC_IGNORED, "IDE_DIAGNOSTIC_IGNORED", "ignored" },
            { IDE_DIAGNOSTIC_NOTE, "IDE_DIAGNOSTIC_NOTE", "note" },
            { IDE_DIAGNOSTIC_DEPRECATED, "IDE_DIAGNOSTIC_DEPRECATED", "deprecated" },
            { IDE_DIAGNOSTIC_WARNING, "IDE_DIAGNOSTIC_WARNING", "warning" },
            { IDE_DIAGNOSTIC_ERROR, "IDE_DIAGNOSTIC_ERROR", "error" },
            { IDE_DIAGNOSTIC_FATAL, "IDE_DIAGNOSTIC_FATAL", "fatal" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static (g_intern_static_string ("IdeDiagnosticSeverity"), values);
    }
    return etype;
}

/* enumerations from "./ide-highlighter.h" */
GType
ide_highlight_result_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GEnumValue values[] = {
            { IDE_HIGHLIGHT_STOP, "IDE_HIGHLIGHT_STOP", "stop" },
            { IDE_HIGHLIGHT_CONTINUE, "IDE_HIGHLIGHT_CONTINUE", "continue" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static (g_intern_static_string ("IdeHighlightResult"), values);
    }
    return etype;
}

/* enumerations from "./ide-indent-style.h" */
GType
ide_indent_style_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GEnumValue values[] = {
            { IDE_INDENT_STYLE_SPACES, "IDE_INDENT_STYLE_SPACES", "spaces" },
            { IDE_INDENT_STYLE_TABS, "IDE_INDENT_STYLE_TABS", "tabs" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static (g_intern_static_string ("IdeIndentStyle"), values);
    }
    return etype;
}

/* enumerations from "./ide-source-view.h" */
GType
ide_source_view_mode_type_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GEnumValue values[] = {
            { IDE_SOURCE_VIEW_MODE_TYPE_TRANSIENT, "IDE_SOURCE_VIEW_MODE_TYPE_TRANSIENT", "transient" },
            { IDE_SOURCE_VIEW_MODE_TYPE_PERMANENT, "IDE_SOURCE_VIEW_MODE_TYPE_PERMANENT", "permanent" },
            { IDE_SOURCE_VIEW_MODE_TYPE_MODAL, "IDE_SOURCE_VIEW_MODE_TYPE_MODAL", "modal" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static (g_intern_static_string ("IdeSourceViewModeType"), values);
    }
    return etype;
}

GType
ide_source_view_theatric_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GEnumValue values[] = {
            { IDE_SOURCE_VIEW_THEATRIC_EXPAND, "IDE_SOURCE_VIEW_THEATRIC_EXPAND", "expand" },
            { IDE_SOURCE_VIEW_THEATRIC_SHRINK, "IDE_SOURCE_VIEW_THEATRIC_SHRINK", "shrink" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static (g_intern_static_string ("IdeSourceViewTheatric"), values);
    }
    return etype;
}

GType
ide_source_view_movement_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GEnumValue values[] = {
            { IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_OFFSET, "IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_OFFSET", "previous-offset" },
            { IDE_SOURCE_VIEW_MOVEMENT_NEXT_OFFSET, "IDE_SOURCE_VIEW_MOVEMENT_NEXT_OFFSET", "next-offset" },
            { IDE_SOURCE_VIEW_MOVEMENT_NTH_CHAR, "IDE_SOURCE_VIEW_MOVEMENT_NTH_CHAR", "nth-char" },
            { IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_CHAR, "IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_CHAR", "previous-char" },
            { IDE_SOURCE_VIEW_MOVEMENT_NEXT_CHAR, "IDE_SOURCE_VIEW_MOVEMENT_NEXT_CHAR", "next-char" },
            { IDE_SOURCE_VIEW_MOVEMENT_FIRST_CHAR, "IDE_SOURCE_VIEW_MOVEMENT_FIRST_CHAR", "first-char" },
            { IDE_SOURCE_VIEW_MOVEMENT_FIRST_NONSPACE_CHAR, "IDE_SOURCE_VIEW_MOVEMENT_FIRST_NONSPACE_CHAR", "first-nonspace-char" },
            { IDE_SOURCE_VIEW_MOVEMENT_MIDDLE_CHAR, "IDE_SOURCE_VIEW_MOVEMENT_MIDDLE_CHAR", "middle-char" },
            { IDE_SOURCE_VIEW_MOVEMENT_LAST_CHAR, "IDE_SOURCE_VIEW_MOVEMENT_LAST_CHAR", "last-char" },
            { IDE_SOURCE_VIEW_MOVEMENT_NEXT_WORD_START, "IDE_SOURCE_VIEW_MOVEMENT_NEXT_WORD_START", "next-word-start" },
            { IDE_SOURCE_VIEW_MOVEMENT_NEXT_FULL_WORD_START, "IDE_SOURCE_VIEW_MOVEMENT_NEXT_FULL_WORD_START", "next-full-word-start" },
            { IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_WORD_START, "IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_WORD_START", "previous-word-start" },
            { IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_FULL_WORD_START, "IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_FULL_WORD_START", "previous-full-word-start" },
            { IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_WORD_END, "IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_WORD_END", "previous-word-end" },
            { IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_FULL_WORD_END, "IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_FULL_WORD_END", "previous-full-word-end" },
            { IDE_SOURCE_VIEW_MOVEMENT_NEXT_WORD_END, "IDE_SOURCE_VIEW_MOVEMENT_NEXT_WORD_END", "next-word-end" },
            { IDE_SOURCE_VIEW_MOVEMENT_NEXT_FULL_WORD_END, "IDE_SOURCE_VIEW_MOVEMENT_NEXT_FULL_WORD_END", "next-full-word-end" },
            { IDE_SOURCE_VIEW_MOVEMENT_SENTENCE_START, "IDE_SOURCE_VIEW_MOVEMENT_SENTENCE_START", "sentence-start" },
            { IDE_SOURCE_VIEW_MOVEMENT_SENTENCE_END, "IDE_SOURCE_VIEW_MOVEMENT_SENTENCE_END", "sentence-end" },
            { IDE_SOURCE_VIEW_MOVEMENT_PARAGRAPH_START, "IDE_SOURCE_VIEW_MOVEMENT_PARAGRAPH_START", "paragraph-start" },
            { IDE_SOURCE_VIEW_MOVEMENT_PARAGRAPH_END, "IDE_SOURCE_VIEW_MOVEMENT_PARAGRAPH_END", "paragraph-end" },
            { IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_LINE, "IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_LINE", "previous-line" },
            { IDE_SOURCE_VIEW_MOVEMENT_NEXT_LINE, "IDE_SOURCE_VIEW_MOVEMENT_NEXT_LINE", "next-line" },
            { IDE_SOURCE_VIEW_MOVEMENT_FIRST_LINE, "IDE_SOURCE_VIEW_MOVEMENT_FIRST_LINE", "first-line" },
            { IDE_SOURCE_VIEW_MOVEMENT_NTH_LINE, "IDE_SOURCE_VIEW_MOVEMENT_NTH_LINE", "nth-line" },
            { IDE_SOURCE_VIEW_MOVEMENT_LAST_LINE, "IDE_SOURCE_VIEW_MOVEMENT_LAST_LINE", "last-line" },
            { IDE_SOURCE_VIEW_MOVEMENT_LINE_PERCENTAGE, "IDE_SOURCE_VIEW_MOVEMENT_LINE_PERCENTAGE", "line-percentage" },
            { IDE_SOURCE_VIEW_MOVEMENT_LINE_CHARS, "IDE_SOURCE_VIEW_MOVEMENT_LINE_CHARS", "line-chars" },
            { IDE_SOURCE_VIEW_MOVEMENT_LINE_END, "IDE_SOURCE_VIEW_MOVEMENT_LINE_END", "line-end" },
            { IDE_SOURCE_VIEW_MOVEMENT_HALF_PAGE_UP, "IDE_SOURCE_VIEW_MOVEMENT_HALF_PAGE_UP", "half-page-up" },
            { IDE_SOURCE_VIEW_MOVEMENT_HALF_PAGE_DOWN, "IDE_SOURCE_VIEW_MOVEMENT_HALF_PAGE_DOWN", "half-page-down" },
            { IDE_SOURCE_VIEW_MOVEMENT_PAGE_UP, "IDE_SOURCE_VIEW_MOVEMENT_PAGE_UP", "page-up" },
            { IDE_SOURCE_VIEW_MOVEMENT_PAGE_DOWN, "IDE_SOURCE_VIEW_MOVEMENT_PAGE_DOWN", "page-down" },
            { IDE_SOURCE_VIEW_MOVEMENT_SCREEN_UP, "IDE_SOURCE_VIEW_MOVEMENT_SCREEN_UP", "screen-up" },
            { IDE_SOURCE_VIEW_MOVEMENT_SCREEN_DOWN, "IDE_SOURCE_VIEW_MOVEMENT_SCREEN_DOWN", "screen-down" },
            { IDE_SOURCE_VIEW_MOVEMENT_SCREEN_TOP, "IDE_SOURCE_VIEW_MOVEMENT_SCREEN_TOP", "screen-top" },
            { IDE_SOURCE_VIEW_MOVEMENT_SCREEN_MIDDLE, "IDE_SOURCE_VIEW_MOVEMENT_SCREEN_MIDDLE", "screen-middle" },
            { IDE_SOURCE_VIEW_MOVEMENT_SCREEN_BOTTOM, "IDE_SOURCE_VIEW_MOVEMENT_SCREEN_BOTTOM", "screen-bottom" },
            { IDE_SOURCE_VIEW_MOVEMENT_MATCH_SPECIAL, "IDE_SOURCE_VIEW_MOVEMENT_MATCH_SPECIAL", "match-special" },
            { IDE_SOURCE_VIEW_MOVEMENT_SCROLL_SCREEN_TOP, "IDE_SOURCE_VIEW_MOVEMENT_SCROLL_SCREEN_TOP", "scroll-screen-top" },
            { IDE_SOURCE_VIEW_MOVEMENT_SCROLL_SCREEN_CENTER, "IDE_SOURCE_VIEW_MOVEMENT_SCROLL_SCREEN_CENTER", "scroll-screen-center" },
            { IDE_SOURCE_VIEW_MOVEMENT_SCROLL_SCREEN_BOTTOM, "IDE_SOURCE_VIEW_MOVEMENT_SCROLL_SCREEN_BOTTOM", "scroll-screen-bottom" },
            { IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_UNMATCHED_BRACE, "IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_UNMATCHED_BRACE", "previous-unmatched-brace" },
            { IDE_SOURCE_VIEW_MOVEMENT_NEXT_UNMATCHED_BRACE, "IDE_SOURCE_VIEW_MOVEMENT_NEXT_UNMATCHED_BRACE", "next-unmatched-brace" },
            { IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_UNMATCHED_PAREN, "IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_UNMATCHED_PAREN", "previous-unmatched-paren" },
            { IDE_SOURCE_VIEW_MOVEMENT_NEXT_UNMATCHED_PAREN, "IDE_SOURCE_VIEW_MOVEMENT_NEXT_UNMATCHED_PAREN", "next-unmatched-paren" },
            { IDE_SOURCE_VIEW_MOVEMENT_NEXT_MATCH_MODIFIER, "IDE_SOURCE_VIEW_MOVEMENT_NEXT_MATCH_MODIFIER", "next-match-modifier" },
            { IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_MATCH_MODIFIER, "IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_MATCH_MODIFIER", "previous-match-modifier" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static (g_intern_static_string ("IdeSourceViewMovement"), values);
    }
    return etype;
}

/* enumerations from "./ide-symbol.h" */
GType
ide_symbol_kind_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GEnumValue values[] = {
            { IDE_SYMBOL_NONE, "IDE_SYMBOL_NONE", "none" },
            { IDE_SYMBOL_SCALAR, "IDE_SYMBOL_SCALAR", "scalar" },
            { IDE_SYMBOL_CLASS, "IDE_SYMBOL_CLASS", "class" },
            { IDE_SYMBOL_FUNCTION, "IDE_SYMBOL_FUNCTION", "function" },
            { IDE_SYMBOL_METHOD, "IDE_SYMBOL_METHOD", "method" },
            { IDE_SYMBOL_STRUCT, "IDE_SYMBOL_STRUCT", "struct" },
            { IDE_SYMBOL_UNION, "IDE_SYMBOL_UNION", "union" },
            { IDE_SYMBOL_FIELD, "IDE_SYMBOL_FIELD", "field" },
            { IDE_SYMBOL_ENUM, "IDE_SYMBOL_ENUM", "enum" },
            { IDE_SYMBOL_ENUM_VALUE, "IDE_SYMBOL_ENUM_VALUE", "enum-value" },
            { IDE_SYMBOL_VARIABLE, "IDE_SYMBOL_VARIABLE", "variable" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static (g_intern_static_string ("IdeSymbolKind"), values);
    }
    return etype;
}

GType
ide_symbol_flags_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GFlagsValue values[] = {
            { IDE_SYMBOL_FLAGS_NONE, "IDE_SYMBOL_FLAGS_NONE", "symbol-flags-none" },
            { IDE_SYMBOL_FLAGS_IS_STATIC, "IDE_SYMBOL_FLAGS_IS_STATIC", "symbol-flags-is-static" },
            { IDE_sYMBOL_FLAGS_IS_MEMBER, "IDE_sYMBOL_FLAGS_IS_MEMBER", "symbol-flags-is-member" },
            { IDE_SYMBOL_FLAGS_IS_DEPRECATED, "IDE_SYMBOL_FLAGS_IS_DEPRECATED", "symbol-flags-is-deprecated" },
            { 0, NULL, NULL }
        };
        etype = g_flags_register_static (g_intern_static_string ("IdeSymbolFlags"), values);
    }
    return etype;
}

/* enumerations from "./ide-thread-pool.h" */
GType
ide_thread_pool_kind_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GEnumValue values[] = {
            { IDE_THREAD_POOL_COMPILER, "IDE_THREAD_POOL_COMPILER", "compiler" },
            { IDE_THREAD_POOL_INDEXER, "IDE_THREAD_POOL_INDEXER", "indexer" },
            { IDE_THREAD_POOL_LAST, "IDE_THREAD_POOL_LAST", "last" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static (g_intern_static_string ("IdeThreadPoolKind"), values);
    }
    return etype;
}



/* Generated data ends here */
